@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0307';
+our $VERSION = '0.0308';
 
 use Moo;
 use strictures 2;
@@ -244,7 +244,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0307
+version 0.0308
 
 =head1 SYNOPSIS
 
@@ -287,8 +287,8 @@ constructor. Unbound arguments will return all the possible values
 that make the query true.
 
 The essential question is, "Can a chord in one key function in a
-second?" Any B<any> parts of this open-ended question may be unbound,
-thereby resulting in all possible truths.
+second?" Any parts of this open-ended question may be unbound, thereby
+resulting in all possible truths.
 
 =head1 ATTRIBUTES
 
@@ -397,6 +397,9 @@ L<https://en.wikipedia.org/wiki/Prolog>
 
 L<https://en.wikipedia.org/wiki/Common_chord_(music)>
 
+L<https://ology.github.io/2023/06/05/querying-a-music-theory-database/>
+is the write-up about using this module
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
